@@ -1,7 +1,7 @@
 from five import grok
 
 from zope.schema import TextLine, Text
-from zope.schema import URI
+from zope.interface import Interface
 from plone.memoize import view
 from plone.namedfile.field import NamedImage
 from plone.directives import form
@@ -15,7 +15,7 @@ from seantis.dir.base.interfaces import (
     IDirectoryItem
 )
 from seantis.dir.base.fieldmap import FieldMap
-from seantis.dir.base.schemafields import Email
+from seantis.dir.base.schemafields import Email, AutoProtocolURI
 
 from seantis.dir.contacts import _
 from seantis.dir.contacts.directory import IContactsDirectory
@@ -67,7 +67,7 @@ class IContactsDirectoryItem(IDirectoryItem):
     )
 
     searchable('url')
-    url = URI(
+    url = AutoProtocolURI(
         title=_(u'Internet Address'),
         required=False,
         default=None
@@ -101,7 +101,7 @@ class ContactsDirectoryItem(DirectoryItem):
 
 
 class ContactsDirectoryItemViewlet(grok.Viewlet):
-    grok.context(IContactsDirectoryItem)
+    grok.context(Interface)
     grok.name('seantis.dir.contacts.item.detail')
     grok.require('zope2.View')
     grok.viewletmanager(DirectoryItemViewletManager)
@@ -154,7 +154,7 @@ class ExtendedDirectoryItemFieldMap(grok.Adapter):
         itemmap.add_fields(extended, len(itemmap))
 
         contactfields = ['first_name', 'last_name',
-                         'street', 'zipcode', 'phone',
+                         'street', 'zipcode', 'town', 'phone',
                          'fax', 'email', 'function']
 
         contactmap = FieldMap()
